`Problem Set: propositional`

# The Lost Key

A logic problem by Brandon Bennett

Your problem is to use propositional logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

Use the following template file to create your Prover9 encoding of the problem: `lost_key.p9`

Marks: There are two marks for each sentence, making a total of 10 marks.

## Problem Statement

A1 | If Alan did not lock the door he either forgot or lost the key.
A2 | If he lost the key he will be in trouble.
A3 | If he has a good memory he did not forget.
A4 | Alan has a good memory.
Goal | Either Alan locked the door or he will be in trouble.

### Non-Logical Vocabulary

Propositional Constants: `AlanLockedDoor`, `AlanForgotKey`, `AlanLostKey`, `AlanInTrouble`, `AlanGoodMemory`